@@ -1,10 +1,10 @@
 #! /bin/sh
 
-# Copyright (C) 2001-2005 Peter Selinger.
-# This file is part of potrace. It is free software and it is covered
+# Copyright (C) 2001-2007 Peter Selinger.
+# This file is part of Potrace. It is free software and it is covered
 # by the GNU General Public License. See the file COPYING for details.
 
-if [ "$#" -gt 0 ] && [ "$1" = "-t" ]; then
+if test "$#" -gt 0 -a "$1" = "-t"; then
     testflag=yes
 fi
 
@@ -17,7 +17,7 @@ echo "Checking backends..." >& 2
 # coding. The main point of this test is to exercise as many parts of
 # the backend code as possible.
 
-if [ -z "$srcdir" ]; then
+if test -z "$srcdir"; then
     srcdir=.
 fi
 
@@ -34,7 +34,7 @@ DATASIZE=5956
 # run the command, expecting return value 0
 action () {
     "$@"
-    if [ "$?" -ne 0 ]; then
+    if test "$?" -ne 0; then
 	echo "$NAME: test failed" >& 2
 	echo "Failed command: $LINE: $@" >& 2
 	exit 1
@@ -48,10 +48,10 @@ alias action="LINE=\$LINENO; action"
 getsize () {
     F="$1"
     set dummy `ls -l "$DATA"`
-    if [ "$6" = "$DATASIZE" ]; then
+    if test "$6" = "$DATASIZE"; then
         set dummy `ls -l "$F"`
 	echo "$6"
-    elif [ "$5" = "$DATASIZE" ]; then
+    elif test "$5" = "$DATASIZE"; then
 	set dummy `ls -l "$F"`
 	echo "$5"
     else
@@ -73,11 +73,11 @@ sizetest () {
     L="$2"
     U="$3"
     S=`getsize "$F"`
-    if [ "$testflag" = "yes" ]; then
+    if test "$testflag" = "yes"; then
 	echo "Size: $S, Bounds: $L $U" >& 2
 	return 0;
     fi
-    if [ "$S" -lt "$L" ] || [ "$S" -gt "$U" ]; then
+    if test "$S" -lt "$L" -o "$S" -gt "$U"; then
 	echo "File size: $S" >& 2
 	return 1;
     fi
@@ -97,7 +97,7 @@ action sizetest "$TMP1" 9000 9800
 
 # test eps with level 2 compression
 R=`action $POTRACE -2 -o "$TMP1" "$DATA" 2>&1`
-if [ "$?" -ne 0 ]; then
+if test "$?" -ne 0; then
     exit
 fi
 if echo "$R" | grep 'option -2 not supported' > /dev/null ; then
@@ -109,7 +109,7 @@ fi
 
 # test eps with level 3 compression
 R=`action $POTRACE -3 -o "$TMP1" "$DATA" 2>&1`
-if [ "$?" -ne 0 ]; then
+if test "$?" -ne 0; then
     exit
 fi
 if echo "$R" | grep 'option -3 not supported' > /dev/null ; then
