@@ -1,7 +1,7 @@
 #! /bin/sh
 
-# Copyright (C) 2001-2005 Peter Selinger.
-# This file is part of potrace. It is free software and it is covered
+# Copyright (C) 2001-2007 Peter Selinger.
+# This file is part of Potrace. It is free software and it is covered
 # by the GNU General Public License. See the file COPYING for details.
 
 echo "Checking input formats..." >& 2
@@ -9,7 +9,7 @@ echo "Checking input formats..." >& 2
 # we check that potrace can read different file formats without error,
 # and produces identical output irrespective of the input file format.
 
-if [ -z "$srcdir" ]; then
+if test -z "$srcdir"; then
     srcdir=.
 fi
 
@@ -24,7 +24,7 @@ TMP2=`mktemp "$TMPDIR/$NAME-2.XXXXXX"`
 
 action () {
     "$@"
-    if [ $? -ne 0 ]; then
+    if test $? -ne 0; then
 	echo "$NAME: test failed" >& 2
 	echo "Failed command: $LINE: $@" >& 2
 	exit 1
