@@ -1,7 +1,7 @@
 #! /bin/sh
 
-# Copyright (C) 2001-2005 Peter Selinger.
-# This file is part of potrace. It is free software and it is covered
+# Copyright (C) 2001-2007 Peter Selinger.
+# This file is part of Potrace. It is free software and it is covered
 # by the GNU General Public License. See the file COPYING for details.
 
 echo "Checking mkbitmap..." >& 2
@@ -10,7 +10,7 @@ echo "Checking mkbitmap..." >& 2
 # output is identical to its reference; instead, we compare pixmaps
 # and allow for small differences.
 
-if [ -z "$srcdir" ]; then
+if test -z "$srcdir"; then
     srcdir=.
 fi
 
@@ -28,7 +28,7 @@ REFDATA2="$srcdir/data2.pbm.out2"
 
 action () {
     "$@"
-    if [ $? -ne 0 ]; then
+    if test $? -ne 0; then
 	echo "$NAME: test failed" >& 2
 	echo "Failed command: $LINE: $@" >& 2
 	exit 1
@@ -38,11 +38,11 @@ action () {
 actiondiff () {
     D=`action "$PGMDIFF" "$1" "$2"`
     # check return value because subshell can't exit
-    if [ $? -ne 0 ]; then 
+    if test $? -ne 0; then 
 	exit 1; 
     fi
     echo "Difference: $D" >& 2
-    if [ "$D" -gt "$3" ]; then
+    if test "$D" -gt "$3"; then
 	echo "$NAME: test failed" >& 2
 	echo "Failed command: $LINE: $PGMDIFF $1 $2" >& 2
 	exit 1;
