@@ -1,8 +1,8 @@
-/* Copyright (C) 2001-2005 Peter Selinger.
-   This file is part of potrace. It is free software and it is covered
+/* Copyright (C) 2001-2007 Peter Selinger.
+   This file is part of Potrace. It is free software and it is covered
    by the GNU General Public License. See the file COPYING for details. */
 
-/* $Id: pgmdiff.c,v 1.7 2005/02/22 21:31:23 selinger Exp $ */
+/* $Id: pgmdiff.c 147 2007-04-09 00:44:09Z selinger $ */
 
 /* This program compares two equal sized PGM files and outputs a
    numerical difference, which is proportional to the sum of the
@@ -24,6 +24,8 @@ int main(int ac, char **av) {
   double diff;
   int x, y, d;
 
+  platform_init();
+
   if (ac != 3) {
     fprintf(stderr, "pgmdiff: wrong number of arguments\n");
     fprintf(stderr, "Usage: pgmdiff file1 file2\n");
@@ -38,7 +40,7 @@ int main(int ac, char **av) {
   if (strcmp(file1, "-")==0) {
     r = gm_read(stdin, &g1);
   } else {
-    f = fopen(file1, "r");
+    f = fopen(file1, "rb");
     if (!f) {
       fprintf(stderr, "pgmdiff: %s: %s\n", file1, strerror(errno));
       return 2;
@@ -57,7 +59,7 @@ int main(int ac, char **av) {
   if (strcmp(file2, "-")==0) {
     r = gm_read(stdin, &g2);
   } else {
-    f = fopen(file2, "r");
+    f = fopen(file2, "rb");
     if (!f) {
       fprintf(stderr, "pgmdiff: %s: %s\n", file2, strerror(errno));
       return 2;
