@@ -1,7 +1,7 @@
 #! /bin/sh
 
-# Copyright (C) 2001-2005 Peter Selinger.
-# This file is part of potrace. It is free software and it is covered
+# Copyright (C) 2001-2007 Peter Selinger.
+# This file is part of Potrace. It is free software and it is covered
 # by the GNU General Public License. See the file COPYING for details.
 
 echo "Checking algorithm..." >& 2
@@ -10,7 +10,7 @@ echo "Checking algorithm..." >& 2
 # output is identical to its reference; instead, we compare greymaps
 # and allow for small differences.
 
-if [ -z "$srcdir" ]; then
+if test -z "$srcdir"; then
     srcdir=.
 fi
 
@@ -24,12 +24,13 @@ TMPDIR="${TEMPDIR:-/tmp}"
 TMP1=`mktemp "$TMPDIR/$NAME-1.XXXXXX"`
 DATA="$srcdir/data1.pbm"
 REFDATA="$srcdir/data1.pgm.out"
+REFDATAROT="$srcdir/data1.pgm.rot"
 EDATA="$srcdir/data3.pgm"
 EREFDATA="$srcdir/data3.pgm"
 
 action () {
     "$@"
-    if [ $? -ne 0 ]; then
+    if test $? -ne 0; then
 	echo "$NAME: test failed" >& 2
 	echo "Failed command: $LINE: $@" >& 2
 	exit 1
@@ -39,11 +40,11 @@ action () {
 actiondiff () {
     D=`action "$PGMDIFF" "$1" "$2"`
     # check return value because subshell can't exit
-    if [ $? -ne 0 ]; then 
+    if test $? -ne 0; then 
 	exit 1; 
     fi
     echo "Difference: $D" >& 2
-    if [ "$D" -gt "$3" ]; then
+    if test "$D" -gt "$3"; then
 	echo "$NAME: test failed" >& 2
 	echo "Failed command: $LINE: $PGMDIFF $1 $2" >& 2
 	exit 1;
@@ -60,6 +61,9 @@ actiondiff "$TMP1" "$REFDATA" 50
 action $POTRACE -n -g -o "$TMP1" "$DATA"
 actiondiff "$TMP1" "$REFDATA" 50
 
+action $POTRACE -n -g -A 160 -o "$TMP1" "$DATA"
+actiondiff "$TMP1" "$REFDATAROT" 50
+
 # check that potrace works on an empty bitmap
 action $POTRACE -g -o "$TMP1" "$EDATA"
 actiondiff "$TMP1" "$EREFDATA" 0
