@@ -1,10 +1,10 @@
-/* Copyright (C) 2001-2005 Peter Selinger.
-   This file is part of potrace. It is free software and it is covered
+/* Copyright (C) 2001-2007 Peter Selinger.
+   This file is part of Potrace. It is free software and it is covered
    by the GNU General Public License. See the file COPYING for details. */
 
-/* $Id: backend_pdf.c,v 1.10 2005/02/22 21:31:23 selinger Exp $ */
+/* $Id: backend_pdf.c 147 2007-04-09 00:44:09Z selinger $ */
 
-/* The PDF backend of potrace. Stream compression is optionally
+/* The PDF backend of Potrace. Stream compression is optionally
 	supplied via the functions in flate.c. */
 
 #include <stdio.h>
@@ -108,8 +108,8 @@ static int ship(const char *fmt, ...) {
   return 0;
 }  
 
-/* ship a PDF comment, unfiltered */
-static int shipcom(char *fmt, ...) {
+/* ship PDF code, unfiltered */
+static int shipclear(char *fmt, ...) {
   static char buf[4096];
   va_list args;
 
@@ -125,10 +125,6 @@ static int shipcom(char *fmt, ...) {
 /* set all callback functions */
 static void pdf_callbacks(FILE *fout) {
 
-#ifndef HAVE_ZLIB
-  info.compress = 0;
-#endif
-
   if (info.compress) {
     xship = pdf_xship;
   } else {
@@ -286,15 +282,15 @@ int init_pdf(FILE *fout)
 	pdf_callbacks(fout);
 	outcount = 0;
 
-	shipcom("%%PDF-1.3\n");
+	shipclear("%%PDF-1.3\n");
 
 	intarray_set(&xref, nxref++, outcount);
-	shipcom("1 0 obj\n<</Type/Catalog/Pages 3 0 R>>\nendobj\n");
+	shipclear("1 0 obj\n<</Type/Catalog/Pages 3 0 R>>\nendobj\n");
 
 	intarray_set(&xref, nxref++, outcount);
-	shipcom("2 0 obj\n"
+	shipclear("2 0 obj\n"
 		"<</Creator"
-		"("POTRACE" "VERSION", written by Peter Selinger 2001-2005)>>\n"
+		"("POTRACE" "VERSION", written by Peter Selinger 2001-2007)>>\n"
 		"endobj\n");
 
 	/* delay obj #3 (pages) until end */
@@ -312,21 +308,21 @@ int term_pdf(FILE *fout)
 	pdf_callbacks(fout);
 
 	intarray_set(&xref, 2, outcount);
-	shipcom("3 0 obj\n"
+	shipclear("3 0 obj\n"
 		"<</Type/Pages/Count %d/Kids[\n", npages);
 	for (i = 0; i < npages; i++)
-		shipcom("%d 0 R\n", pages.data[i]);
-	shipcom("]>>\nendobj\n");
+		shipclear("%d 0 R\n", pages.data[i]);
+	shipclear("]>>\nendobj\n");
 
 	startxref = outcount;
 
-	shipcom("xref\n0 %d\n", nxref + 1);
-	shipcom("0000000000 65535 f \n");
+	shipclear("xref\n0 %d\n", nxref + 1);
+	shipclear("0000000000 65535 f \n");
 	for (i = 0; i < nxref; i++)
-		shipcom("%0.10d 00000 n \n", xref.data[i]);
+		shipclear("%0.10d 00000 n \n", xref.data[i]);
 
-	shipcom("trailer\n<</Size %d/Root 1 0 R/Info 2 0 R>>\n", nxref + 1);
-	shipcom("startxref\n%d\n%%%%EOF\n", startxref);
+	shipclear("trailer\n<</Size %d/Root 1 0 R/Info 2 0 R>>\n", nxref + 1);
+	shipclear("startxref\n%d\n%%%%EOF\n", startxref);
 
 	fflush(fout);
 	intarray_term(&xref);
@@ -336,6 +332,8 @@ int term_pdf(FILE *fout)
 
 static void pdf_pageinit(imginfo_t *imginfo)
 {
+	double s, c;
+
 	double origx = imginfo->trans.orig[0] + imginfo->lmar;
 	double origy = imginfo->trans.orig[1] + imginfo->bmar;
 	double scalex = imginfo->width / imginfo->pixwidth / info.unit;
@@ -347,39 +345,41 @@ static void pdf_pageinit(imginfo_t *imginfo)
 	pdf_width = -1;
 
 	intarray_set(&xref, nxref++, outcount);
-	shipcom("%d 0 obj\n", nxref);
-	shipcom("<</Type/Page/Parent 3 0 R/Resources<</ProcSet[/PDF]>>");
-	shipcom("/MediaBox[0 0 %d %d]", pagew, pageh);
-	shipcom("/Contents %d 0 R>>\n", nxref + 1);
-	shipcom("endobj\n");
+	shipclear("%d 0 obj\n", nxref);
+	shipclear("<</Type/Page/Parent 3 0 R/Resources<</ProcSet[/PDF]>>");
+	shipclear("/MediaBox[0 0 %d %d]", pagew, pageh);
+	shipclear("/Contents %d 0 R>>\n", nxref + 1);
+	shipclear("endobj\n");
 
 	intarray_set(&pages, npages++, nxref);
 
 	intarray_set(&xref, nxref++, outcount);
-	shipcom("%d 0 obj\n", nxref);
+	shipclear("%d 0 obj\n", nxref);
 	if (info.compress)
-		shipcom("<</Filter/FlateDecode/Length %d 0 R>>\n", nxref + 1);
+		shipclear("<</Filter/FlateDecode/Length %d 0 R>>\n", nxref + 1);
 	else
-		shipcom("<</Length %d 0 R>>\n", nxref + 1);
-	shipcom("stream\n");
+		shipclear("<</Length %d 0 R>>\n", nxref + 1);
+	shipclear("stream\n");
 
 	streamofs = outcount;
 
-	/* TODO: info.angle rotate */
-	ship("%f 0 0 %f %.0f %.0f cm\n", scalex, scaley, origx, origy);
+	s = sin(info.angle * M_PI / 180.0);
+	c = cos(info.angle * M_PI / 180.0);
+
+	ship("%f %f %f %f %.0f %.0f cm\n", scalex*c, scalex*s, -scaley*s, scaley*c, origx, origy);
 }
 
-static void pdf_pageterm()
+static void pdf_pageterm(void)
 {
 	int streamlen;
 
-	shipcom("");
+	shipclear("");
 
 	streamlen = outcount - streamofs;
-	shipcom("endstream\nendobj\n");
+	shipclear("endstream\nendobj\n");
 	
 	intarray_set(&xref, nxref++, outcount);
-	shipcom("%d 0 obj\n%d\nendobj\n", nxref, streamlen);
+	shipclear("%d 0 obj\n%d\nendobj\n", nxref, streamlen);
 }
 
 int page_pdf(FILE *fout, potrace_path_t *plist, imginfo_t *imginfo)
