@@ -1,8 +1,8 @@
-/* Copyright (C) 2001-2005 Peter Selinger.
-   This file is part of potrace. It is free software and it is covered
+/* Copyright (C) 2001-2007 Peter Selinger.
+   This file is part of Potrace. It is free software and it is covered
    by the GNU General Public License. See the file COPYING for details. */
 
-/* $Id: main.c,v 1.41 2005/02/22 21:31:23 selinger Exp $ */
+/* $Id: main.c 147 2007-04-09 00:44:09Z selinger $ */
 
 #include <stdio.h>
 #include <stdlib.h>
@@ -36,7 +36,7 @@
 #define UNDEF ((double)(1e30))   /* a value to represent "undefined" */
 #define INFTY ((double)(1e30))   /* a value to represent +infinity */
 
-struct info info;
+struct info_s info;
 
 #define COL0 "\033[G"  /* reset cursor to column 0 */
 
@@ -231,7 +231,7 @@ static int backend_list(FILE *fout, int j, int linelen) {
 /* ---------------------------------------------------------------------- */
 /* some info functions */
 
-static int license(FILE *f) {
+static void license(FILE *f) {
   fprintf(f, 
   "This program is free software; you can redistribute it and/or modify\n"
   "it under the terms of the GNU General Public License as published by\n"
@@ -247,17 +247,15 @@ static int license(FILE *f) {
   "along with this program; if not, write to the Free Software\n"
   "Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307, USA.\n"
 	  );
-  return 0;
 }
 
-static int show_defaults(FILE *f) {
-  fprintf(f, "This version of potrace was compiled with the following defaults:\n");
+static void show_defaults(FILE *f) {
+  fprintf(f, "This version of Potrace was compiled with the following defaults:\n");
   fprintf(f, "Default unit: "DEFAULT_DIM_NAME"\n");
   fprintf(f, "Default page size: "DEFAULT_PAPERFORMAT"\n");
-  return 0;
 }
 
-static int usage(FILE *f) {
+static void usage(FILE *f) {
   int j;
 
   fprintf(f, "Usage: "POTRACE" [options] [file...]\n");
@@ -320,8 +318,6 @@ static int usage(FILE *f) {
   j = fprintf(f, "Backends are: ");
   backend_list(f, j, 70);
   fprintf(f, ".\n");
-  
-  return 0;
 }
 
 /* ---------------------------------------------------------------------- */
@@ -483,7 +479,7 @@ static struct option longopts[] = {
 
 static char *shortopts = "hvlVW:H:r:x:S:M:L:R:T:B:A:P:t:u:c23epsgb:d:C:z:G:nqa:O:o:k:i";
 
-static int dopts(int ac, char *av[]) {
+static void dopts(int ac, char *av[]) {
   int c;
   char *p;
   int i, j, r;
@@ -534,17 +530,17 @@ static int dopts(int ac, char *av[]) {
       exit(0);
       break;
     case 'v':
-      fprintf(stdout, ""POTRACE" "VERSION". Copyright (C) 2001-2005 Peter Selinger.\n");
+      fprintf(stdout, ""POTRACE" "VERSION". Copyright (C) 2001-2007 Peter Selinger.\n");
       fprintf(stdout, "Library version: %s\n", potrace_version());
       exit(0);
       break;
     case 'l':
-      fprintf(stdout, ""POTRACE" "VERSION". Copyright (C) 2001-2005 Peter Selinger.\n\n");
+      fprintf(stdout, ""POTRACE" "VERSION". Copyright (C) 2001-2007 Peter Selinger.\n\n");
       license(stdout);
       exit(0);
       break;
     case 'V':
-      fprintf(stdout, ""POTRACE" "VERSION". Copyright (C) 2001-2005 Peter Selinger.\n");
+      fprintf(stdout, ""POTRACE" "VERSION". Copyright (C) 2001-2007 Peter Selinger.\n");
       show_defaults(stdout);
       exit(0);
       break;
@@ -843,8 +839,6 @@ static int dopts(int ac, char *av[]) {
   }
   info.infiles = &av[optind];
   info.infilecount = ac-optind;
-
-  return 0;
 }
 
 /* ---------------------------------------------------------------------- */
@@ -1024,7 +1018,7 @@ static FILE *my_fopen_read(char *filename) {
   if (filename == NULL || strcmp(filename, "-") == 0) {
     return stdin;
   }
-  return fopen(filename, "r");
+  return fopen(filename, "rb");
 }
 
 /* open a file for writing. Return stdout if filename is NULL or "-" */ 
@@ -1032,7 +1026,7 @@ static FILE *my_fopen_write(char *filename) {
   if (filename == NULL || strcmp(filename, "-") == 0) {
     return stdout;
   }
-  return fopen(filename, "w");
+  return fopen(filename, "wb");
 }
 
 /* close a file, but do nothing is filename is NULL or "-" */
@@ -1172,6 +1166,10 @@ int main(int ac, char *av[]) {
   int i;
   char *outfile;
 
+  /* platform-specific initializations, e.g., set file i/o to binary */
+  platform_init();
+
+  /* process options */
   dopts(ac, av);
 
   b = info.backend;
