@@ -1,8 +1,8 @@
-/* Copyright (C) 2001-2005 Peter Selinger.
-   This file is part of potrace. It is free software and it is covered
+/* Copyright (C) 2001-2007 Peter Selinger.
+   This file is part of Potrace. It is free software and it is covered
    by the GNU General Public License. See the file COPYING for details. */
 
-/* $Id: main.h,v 1.22 2005/02/22 21:31:23 selinger Exp $ */
+/* $Id: main.h 147 2007-04-09 00:44:09Z selinger $ */
 
 #ifndef MAIN_H
 #define MAIN_H
@@ -55,7 +55,7 @@ typedef struct dim_s dim_t;
 struct backend_s;
 
 /* structure to hold command line options */
-struct info {
+struct info_s {
   struct backend_s *backend;  /* type of backend (eps,ps,pgm etc) */
   potrace_param_t *param;  /* tracing parameters, see potracelib.h */
   int debug;         /* type of output (0-2) (for BACKEND_PS/EPS only) */
@@ -85,7 +85,7 @@ struct info {
   int group;         /* group paths together? */
   int progress;      /* should we display a progress bar? */
 };
-typedef struct info info_t;
+typedef struct info_s info_t;
 
 extern info_t info;
 
