@@ -1,5 +1,5 @@
-/* Copyright (C) 2001-2005 Peter Selinger.
-   This file is part of potrace. It is free software and it is covered
+/* Copyright (C) 2001-2007 Peter Selinger.
+   This file is part of Potrace. It is free software and it is covered
    by the GNU General Public License. See the file COPYING for details. */
 
 /* mkbitmap.c: a standalone program for converting greymaps to bitmaps
@@ -502,11 +502,11 @@ static void dopts(int ac, char *av[]) {
       exit(0);
       break;
     case 'v':
-      fprintf(stdout, ""MKBITMAP" "VERSION". Copyright (C) 2001-2005 Peter Selinger.\n");
+      fprintf(stdout, ""MKBITMAP" "VERSION". Copyright (C) 2001-2007 Peter Selinger.\n");
       exit(0);
       break;
     case 'l':
-      fprintf(stdout, ""MKBITMAP" "VERSION". Copyright (C) 2001-2005 Peter Selinger.\n\n");
+      fprintf(stdout, ""MKBITMAP" "VERSION". Copyright (C) 2001-2007 Peter Selinger.\n\n");
       license(stdout);
       exit(0);
       break;
@@ -583,7 +583,7 @@ static FILE *my_fopen_read(char *filename) {
   if (filename == NULL || strcmp(filename, "-") == 0) {
     return stdin;
   }
-  return fopen(filename, "r");
+  return fopen(filename, "rb");
 }
 
 /* open a file for writing. Return stdout if filename is NULL or "-" */ 
@@ -591,7 +591,7 @@ static FILE *my_fopen_write(char *filename) {
   if (filename == NULL || strcmp(filename, "-") == 0) {
     return stdout;
   }
-  return fopen(filename, "w");
+  return fopen(filename, "wb");
 }
 
 /* close a file, but do nothing is filename is NULL or "-" */
@@ -639,6 +639,9 @@ int main(int ac, char *av[]) {
   int i;
   char *outfile;
 
+  /* platform-specific initializations, e.g., set file i/o to binary */
+  platform_init();
+
   /* process options */
   dopts(ac, av);
 
